@@ -1,10 +1,18 @@
+'''
+Date: 2023-03-08 23:10:22
+LastEditors: ThetisEliza wxf199601@gmail.com
+LastEditTime: 2023-03-13 19:34:21
+FilePath: /outlier/test/test_threadpool.py
+'''
 import sys
 import time
 import unittest
 from pathlib import Path
-from tools.threadpool import ThreadPool
 
-sys.path.append(Path(__file__).parent.parent / "src" / "outlier")
+
+# sys.path.append(Path(__file__).parent.parent / "src")
+
+from outlier.tools.threadpool import ThreadPool
 
 class testThreadPool(unittest.TestCase):
     def test_norm(self):
@@ -17,7 +25,7 @@ class testThreadPool(unittest.TestCase):
         t.put_task(ThreadPool.template_loop, args=(3,))
         t.queue.join()
         endtime = time.time()
-        self.assertAlmostEqual(endtime - starttime, 5, delta=0.1)
+        self.assertAlmostEqual(endtime - starttime, 5, delta=0.5)
         
     def test_thread_dead(self):
         starttime = time.time()
@@ -28,4 +36,4 @@ class testThreadPool(unittest.TestCase):
         t.put_task(ThreadPool.template_loop, args=(2,))
         t.queue.join()
         endtime = time.time()
-        self.assertAlmostEqual(endtime - starttime, 5, delta=0.1)
\ No newline at end of file
+        self.assertAlmostEqual(endtime - starttime, 5, delta=0.5)
\ No newline at end of file
